import{e as _,aj as g,r as b,W as y,f as m,g as n,n as d,w as s,v as l,p as r,T as w,q as f,t as u,B as v,l as p,H as h,b8 as k,aP as x}from"./jwt-decode.esm-DRghvhGH.js";import{u as R}from"./organizationSwitcher-BluHzAK8.js";import"./router-COp5Jnuf.js";import"./ts.worker-Drj_VfQm.js";import"./organization-Izq1_XzY.js";import"./tables-Xr3yTzsa.js";import"./string-oqhohvBP.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="0ee08095-2b61-4fe6-81bd-1a760b4bf728",e._sentryDebugIdIdentifier="sentry-dbid-0ee08095-2b61-4fe6-81bd-1a760b4bf728")}catch{}})();const D={class:"loading-container"},I=_({__name:"RootRedirector",setup(e){const a=R(),i=g(),o=b(null);async function c(){o.value=null;try{const t=await a.selectDefaultOrganization();t.name==="onboarding"?window.location.href="/onboarding":i.replace(t)}catch(t){o.value=p.translate("i18n_projectsview_loading_error"),console.error("RootRedirector failed:",t)}}return y(c),(t,B)=>(n(),m("div",D,[o.value?(n(),d(r(h),{key:0,vertical:"",align:"center",gap:16},{default:s(()=>[l(r(w),{type:"danger"},{default:s(()=>[f(u(o.value),1)]),_:1}),l(r(v),{type:"primary",onClick:c},{default:s(()=>[f(u(r(p).translate("i18n_projectsview_retry")),1)]),_:1})]),_:1})):(n(),d(r(k),{key:1,size:"large"}))]))}}),O=x(I,[["__scopeId","data-v-c1eea334"]]);export{O as default};
//# sourceMappingURL=RootRedirector-CoX0Osvy.js.map
