import{_ as c}from"./Login.vue_vue_type_script_setup_true_lang-DmpRGvd2.js";import{e as i,f as u,v as d,p as n,aj as m,an as l,g as f,aP as _}from"./jwt-decode.esm-DRghvhGH.js";import{u as g}from"./workspaceStore-6xAxtabw.js";import"./OTPInput-CZKT9bdY.js";import"./Logo-B9YkLTi0.js";import"./string-oqhohvBP.js";import"./CircularLoading-C7961vxu.js";import"./index-DAL1Eh1-.js";import"./userStore-DJ7XWmCi.js";import"./runnerData-DyO4ndh_.js";import"./url-b_OS5ik_.js";import"./colorHelpers-BNJ_0v5x.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="81347396-17aa-4ed8-b5ea-a2539fa4e720",e._sentryDebugIdIdentifier="sentry-dbid-81347396-17aa-4ed8-b5ea-a2539fa4e720")}catch{}})();const y={class:"runner"},b=i({__name:"Login",setup(e){const o=m(),a=l(),r=g(),p=async()=>{const{redirect:t,...s}=a.query;if(t){await o.push({path:t,query:s,params:a.params});return}o.push({name:"playerHome",query:s})};return(t,s)=>(f(),u("div",y,[d(c,{"logo-url":n(r).state.workspace?.logoUrl??void 0,"brand-name":n(r).state.workspace?.brandName,locale:n(r).state.workspace?.language??"en",onDone:p},null,8,["logo-url","brand-name","locale"])]))}}),R=_(b,[["__scopeId","data-v-12c690e1"]]);export{R as default};
//# sourceMappingURL=Login-Dc6MdDf3.js.map
