import{N as c}from"./Navbar-B_Zcgvy8.js";import{e as d,an as u,b as a,l,a9 as f,f as _,g as y,v as n,k as I,aP as b}from"./jwt-decode.esm-DRghvhGH.js";import"./logo-BiWG9_W5.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang-D0xDi1ue.js";import"./constants-jRdgy-I8.js";import"./PhCaretDown.vue-DKDvKCVm.js";import"./os-DGNBvyYw.js";import"./router-COp5Jnuf.js";import"./ts.worker-Drj_VfQm.js";import"./organization-Izq1_XzY.js";import"./tables-Xr3yTzsa.js";import"./string-oqhohvBP.js";import"./keyboard-DYnDBeV2.js";import"./projectStore-CPohjQMG.js";import"./project-DPCNEC_2.js";import"./organizationSwitcher-BluHzAK8.js";import"./cascaderStore-CC-nSHKt.js";import"./folder-hq2yZXh6.js";import"./CreateProjectModal.vue_vue_type_script_setup_true_lang-DGbd2Uzt.js";import"./member-C68RjPjA.js";import"./index-CTsp-IfN.js";import"./index-CPmfGi-l.js";import"./CreateTableModal.vue_vue_type_script_setup_true_lang-n0qlfaZv.js";import"./PhNotePencil.vue-B5TUXXhC.js";import"./PhSignOut.vue-eUAYwGjL.js";import"./index-CfEctsij.js";import"./index-CmAON_bb.js";import"./PhPlus.vue-TvMOsxzQ.js";import"./omniChatStore-B9fBWpxd.js";import"./contracts.generated-DhIJn8uy.js";import"./runnerData-DyO4ndh_.js";import"./url-b_OS5ik_.js";import"./colorHelpers-BNJ_0v5x.js";import"./uuid-CkgDROLV.js";import"./PhCopySimple.vue-DAytHaSg.js";import"./index-CHsgKaGe.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="99841ae1-ad53-438f-9fe0-9bc3d4eff501",e._sentryDebugIdIdentifier="sentry-dbid-99841ae1-ad53-438f-9fe0-9bc3d4eff501")}catch{}})();const v={class:"console-layout"},g={class:"console-content"},w=d({__name:"ConsoleLayout",setup(e){const o=u(),s=a(()=>!!o.params.projectId),p=a(()=>{const t=o.meta.pageNameKey;if(t)return t.startsWith("i18n_")?l.translateIfFound(t,null):t}),m=a(()=>{const t=o.params.projectId,i=o.params.tableId,r=o.params.organizationId;if(t)return{projectId:t,tableId:i,currentPageName:p.value};if(r)return{organizationId:r}});return(t,i)=>{const r=f("RouterView");return y(),_("div",v,[n(c,{"use-cascader":!0,"cascader-props":m.value,"show-ai-sparkles":s.value},null,8,["cascader-props","show-ai-sparkles"]),I("div",g,[n(r)])])}}}),ao=b(w,[["__scopeId","data-v-62f8634d"]]);export{ao as default};
//# sourceMappingURL=ConsoleLayout-CKITVJlk.js.map
