import{_ as b}from"./AbstraLogo.vue_vue_type_script_setup_true_lang-B-SuDLiJ.js";import{A as h}from"./constants-jRdgy-I8.js";import{e as v,b as y,an as A,l as o,f as B,v as i,n as m,j as p,w as t,p as e,ao as I,b3 as _,B as x,q as a,t as u,k as C,b4 as N,aj as T,g as c,aP as D}from"./jwt-decode.esm-DRghvhGH.js";import{u as E}from"./workspaceStore-6xAxtabw.js";import{C as S}from"./index-CPmfGi-l.js";import"./logo-BiWG9_W5.js";import"./Logo-B9YkLTi0.js";import"./userStore-DJ7XWmCi.js";import"./runnerData-DyO4ndh_.js";import"./url-b_OS5ik_.js";import"./colorHelpers-BNJ_0v5x.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new H().stack;d&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[d]="907f7645-0309-4311-8c2d-e1fa39594700",r._sentryDebugIdIdentifier="sentry-dbid-907f7645-0309-4311-8c2d-e1fa39594700")}catch{}})();const R={class:"inner-content"},V={class:"card-content"},j=v({__name:"Error",setup(r){const d=A(),g=T(),f=E(),w=y(()=>f.state.workspace?.name??f.state.workspace?.brandName),n=y(()=>{const{status:l}=d.params;switch(l){case"404":return{status:l,title:o.translate("i18n_page_not_found"),message:o.translate("i18n_page_not_found_message"),showAd:!1};case"403":return{status:l,title:o.translate("i18n_access_denied"),message:o.translate("i18n_access_denied_message"),action:"Go back to home",showAd:!0};default:return{status:"500",title:o.translate("i18n_internal_error"),message:o.translate("i18n_internal_error_message"),showAd:!1}}}),k=()=>{g.push({name:"playerHome"})};return(l,s)=>(c(),B("div",R,[i(e(I),null,{default:t(()=>[a(u(n.value.title),1)]),_:1}),i(e(_),{class:"message"},{default:t(()=>[a(u(n.value.message),1)]),_:1}),n.value.action?(c(),m(e(x),{key:0,type:"link",onClick:k},{default:t(()=>[a(u(n.value.action),1)]),_:1})):p("",!0),n.value.showAd?(c(),m(e(S),{key:1,bordered:!1,class:"card"},{default:t(()=>[C("div",V,[i(b,{style:{"margin-bottom":"10px"}}),i(e(_),null,{default:t(()=>[a("This page is part of "+u(w.value?`the ${w.value}`:"a")+" workflow, built with Abstra.",1)]),_:1}),e(f).state.workspace?(c(),m(e(_),{key:0},{default:t(()=>[s[1]||(s[1]=a("Automate your own processes by getting started ",-1)),i(e(N),{href:e(h).HOMEPAGE},{default:t(()=>[...s[0]||(s[0]=[a("here",-1)])]),_:1},8,["href"]),s[2]||(s[2]=a(".",-1))]),_:1})):p("",!0)])]),_:1})):p("",!0)]))}}),H=D(j,[["__scopeId","data-v-522ad0d4"]]);export{H as default};
//# sourceMappingURL=Error-CscdjAwE.js.map
