import{C as e,_ as p}from"./View.vue_vue_type_script_setup_true_lang-fHvEn2H2.js";import{e as i,n,g as m,p as a}from"./jwt-decode.esm-DRghvhGH.js";import{u as s}from"./projectStore-CPohjQMG.js";import"./router-COp5Jnuf.js";import"./ts.worker-Drj_VfQm.js";import"./fetch-CzoUzwMe.js";import"./tables-Xr3yTzsa.js";import"./string-oqhohvBP.js";import"./SaveButton-CK9s5NMm.js";import"./ExclamationCircleOutlined-e7p2btno.js";import"./CrudView-D7wGdf9B.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-BqG5zHXY.js";import"./constants-jRdgy-I8.js";import"./url-b_OS5ik_.js";import"./PhDotsThreeVertical.vue-CIChyokh.js";import"./index-CfEctsij.js";import"./asyncComputed-DE90HLZh.js";import"./omniChatStore-B9fBWpxd.js";import"./contracts.generated-DhIJn8uy.js";import"./runnerData-DyO4ndh_.js";import"./colorHelpers-BNJ_0v5x.js";import"./uuid-CkgDROLV.js";import"./PhCopySimple.vue-DAytHaSg.js";import"./PhPencil.vue-DqBAEdD1.js";import"./useCodebaseEvents-LaU8zmkP.js";import"./index-DAL1Eh1-.js";import"./project-DPCNEC_2.js";import"./organizationSwitcher-BluHzAK8.js";import"./organization-Izq1_XzY.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="09a6caa5-f0bc-44cc-a06f-e1ee2202a235",o._sentryDebugIdIdentifier="sentry-dbid-09a6caa5-f0bc-44cc-a06f-e1ee2202a235")}catch{}})();const J=i({__name:"EnvVars",setup(o){const r=s(),t=new e(r.projectId);return(c,f)=>(m(),n(p,{"env-var-repository":a(t),mode:"console"},null,8,["env-var-repository"]))}});export{J as default};
//# sourceMappingURL=EnvVars-BzkT03cR.js.map
