const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["assets/OidcLoginCallback-lrAdwGIi.js","assets/workspaceStore-6xAxtabw.js","assets/jwt-decode.esm-DRghvhGH.js","assets/jwt-decode-CA6P2R_N.css","assets/userStore-DJ7XWmCi.js","assets/runnerData-DyO4ndh_.js","assets/url-b_OS5ik_.js","assets/colorHelpers-BNJ_0v5x.js","assets/OidcLogoutCallback-Cy0VsfQh.js","assets/Login-Dc6MdDf3.js","assets/Login.vue_vue_type_script_setup_true_lang-DmpRGvd2.js","assets/OTPInput-CZKT9bdY.js","assets/OTPInput-DkitIIgo.css","assets/Logo-B9YkLTi0.js","assets/Logo-D2kepPyK.css","assets/string-oqhohvBP.js","assets/CircularLoading-C7961vxu.js","assets/CircularLoading-BiyobKo3.css","assets/index-DAL1Eh1-.js","assets/Login-D3Bo1XNf.css","assets/Login-CobhrWJT.css","assets/Main-ZAO7bVLq.js","assets/PlayerNavbar-2ewOxmRt.js","assets/metadata-P1Jr0bFd.js","assets/PhHouse.vue-DmzIWuil.js","assets/PhMagnifyingGlass.vue-BouCj7uB.js","assets/PhWebhooksLogo.vue-DTqW-wOt.js","assets/LoadingOutlined-DQ4EY_C4.js","assets/PhSignOut.vue-eUAYwGjL.js","assets/index-CmAON_bb.js","assets/PlayerNavbar-CeGdx3sX.css","assets/Main-DqPmGmnC.css","assets/Home-BiJs7Igd.js","assets/Watermark-d4B4um3U.js","assets/constants-jRdgy-I8.js","assets/Watermark-Fl_4jwe9.css","assets/PhArrowSquareOut.vue-D7b48yLf.js","assets/index-CPmfGi-l.js","assets/Home-C1q_HTgM.css","assets/Error-CscdjAwE.js","assets/AbstraLogo.vue_vue_type_script_setup_true_lang-B-SuDLiJ.js","assets/logo-BiWG9_W5.js","assets/Error-CIbhyrKS.css","assets/Form-9BD4YC4A.js","assets/FormRunner-CP1MytoI.js","assets/Steps-LzF26AxU.js","assets/index-BPB02-H4.js","assets/Steps-D24tH1sk.css","assets/FormRunner-Cr_m7D0_.css","assets/redirect-CoqggwyF.js","assets/asyncComputed-DE90HLZh.js","assets/uuid-CkgDROLV.js","assets/Form-CshGBPDC.css"])))=>i.map(i=>d[i]);
import{c as u,a as d,_ as t,u as l}from"./jwt-decode.esm-DRghvhGH.js";import{u as p}from"./userStore-DJ7XWmCi.js";import{a as _}from"./workspaceStore-6xAxtabw.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="cf5accf6-aeb8-4ec9-818d-b0c15c139299",e._sentryDebugIdIdentifier="sentry-dbid-cf5accf6-aeb8-4ec9-818d-b0c15c139299")}catch{}})();const h=[{path:"/oidc-login-callback",name:"oidcLoginCallback",component:()=>t(()=>import("./OidcLoginCallback-lrAdwGIi.js"),__vite__mapDeps([0,1,2,3,4,5,6,7])),meta:{allowUnauthenticated:!0}},{path:"/oidc-logout-callback",name:"oidcLogoutCallback",component:()=>t(()=>import("./OidcLogoutCallback-Cy0VsfQh.js"),__vite__mapDeps([8,1,2,3,4,5,6,7])),meta:{allowUnauthenticated:!0}},{path:"/login",name:"playerLogin",component:()=>t(()=>import("./Login-Dc6MdDf3.js"),__vite__mapDeps([9,10,2,3,1,4,5,6,7,11,12,13,14,15,16,17,18,19,20])),meta:{allowUnauthenticated:!0}},{path:"/",name:"main",component:()=>t(()=>import("./Main-ZAO7bVLq.js"),__vite__mapDeps([21,22,4,2,3,1,5,6,7,23,24,25,26,27,28,29,30,31])),redirect:{name:"main"},children:[{path:"",name:"playerHome",component:()=>t(()=>import("./Home-BiJs7Igd.js"),__vite__mapDeps([32,23,24,2,3,25,26,33,1,4,5,6,7,34,35,36,37,27,38])),meta:{title:"Home"}},{path:"_player/threads",redirect:{name:"playerThreads"}},{path:"error/:status",name:"error",component:()=>t(()=>import("./Error-CscdjAwE.js"),__vite__mapDeps([39,40,41,13,2,3,14,34,1,4,5,6,7,37,42])),meta:{allowUnauthenticated:!0}},{path:":path(.*)*",name:"form",component:()=>t(()=>import("./Form-9BD4YC4A.js"),__vite__mapDeps([43,4,2,3,44,10,1,5,6,7,11,12,13,14,15,16,17,18,19,45,46,47,33,34,35,48,49,50,51,52])),meta:{hideLogin:!0}}]}],i=u({history:d("/"),routes:h,scrollBehavior(e){if(e.hash)return{el:e.hash}}}),f=e=>async(a,o)=>{if(l(a,o),a.meta.allowUnauthenticated)return;const r=p();r.loadJWT();const c=await _(a.path),{redirect:s,...m}=a.query;switch(c.status){case"ALLOWED":break;case"UNAUTHORIZED":{const n=r.email;r.removeJWT(),await e.push({name:"playerLogin",query:{...m,redirect:s||a.path,reauth:n?"true":void 0,email:n||void 0},params:a.params});break}case"NOT_FOUND":await e.push({name:"error",params:{status:"404"}});break;default:await e.push({name:"error",params:{status:"403"}})}};i.beforeEach(f(i));export{h as a,f as g,i as r};
//# sourceMappingURL=router-CC5SKJ6o.js.map
