import{_ as m}from"./AbstraLogo.vue_vue_type_script_setup_true_lang-B-SuDLiJ.js";import{B as y}from"./BaseLayout-DwESOKpN.js";import{e as l,Y as _,a6 as b,aP as u,aK as v,aL as g,g as f,f as h,k as o,P as n,W as w,aj as S,n as k,w as s,an as B,v as i,p as I}from"./jwt-decode.esm-DRghvhGH.js";import{u as L}from"./editor-m3rBI3OZ.js";import{A as P}from"./index-CHsgKaGe.js";import"./logo-BiWG9_W5.js";import"./Logo-B9YkLTi0.js";import"./ts.worker-Drj_VfQm.js";import"./workspaceStore-6xAxtabw.js";import"./userStore-DJ7XWmCi.js";import"./runnerData-DyO4ndh_.js";import"./url-b_OS5ik_.js";import"./colorHelpers-BNJ_0v5x.js";import"./useCodebaseEvents-LaU8zmkP.js";import"./contracts.generated-DhIJn8uy.js";import"./router-CC5SKJ6o.js";import"./constants-jRdgy-I8.js";import"./linters-CHWeJORM.js";import"./asyncComputed-DE90HLZh.js";import"./index-CfEctsij.js";import"./index-CmAON_bb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="4a00e6ec-cb5f-4b3a-996a-51e33f511ec5",e._sentryDebugIdIdentifier="sentry-dbid-4a00e6ec-cb5f-4b3a-996a-51e33f511ec5")}catch{}})();const $=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"var(--ac-brand-primary)"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const r=_({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...b(r)}}}),x={class:"v-spinner"};function D(e,r,a,c,d,p){return v((f(),h("div",x,[o("div",{class:"v-beat v-beat-odd",style:n(e.spinnerStyle)},null,4),o("div",{class:"v-beat v-beat-even",style:n(e.spinnerStyle)},null,4),o("div",{class:"v-beat v-beat-odd",style:n(e.spinnerStyle)},null,4)],512)),[[g,e.loading]])}const K=u($,[["render",D],["__scopeId","data-v-224007fd"]]),R={class:"content"},j=l({__name:"ProjectLogin",setup(e){const r=B(),a=S(),c=L();function d(){const t=new URL(location.href);t.searchParams.delete("api-key"),a.replace(t.pathname+t.search)}function p(){const t=r.query["api-key"];if(typeof t=="string")return t}return w(async()=>{const t=p();if(!t){a.push({name:"error"});return}await c.createLogin(t).then(d),a.push({name:"editor"})}),(t,z)=>(f(),k(y,null,{navbar:s(()=>[i(I(P),{style:{padding:"5px 25px",border:"1px solid var(--ac-border-subtle)"}},{title:s(()=>[i(m)]),_:1})]),content:s(()=>[o("div",R,[i(K)])]),_:1}))}}),re=u(j,[["__scopeId","data-v-c9eeae4b"]]);export{re as default};
//# sourceMappingURL=ProjectLogin-CFdIZfsj.js.map
