import{B as p}from"./BaseLayout-DwESOKpN.js";import{C as l}from"./ContentLayout-mepv5Dmj.js";import{e as f,an as _,b as i,M as g,a9 as b,n as r,g as s,w as m,v as y,j as w}from"./jwt-decode.esm-DRghvhGH.js";import{_ as v}from"./BillingAlert.vue_vue_type_script_setup_true_lang-DWor_gwn.js";import{u as z}from"./projectsStore-BgFUkhs6.js";import"./router-COp5Jnuf.js";import"./ts.worker-Drj_VfQm.js";import"./index-DAL1Eh1-.js";import"./member-C68RjPjA.js";import"./organization-Izq1_XzY.js";import"./project-DPCNEC_2.js";import"./tables-Xr3yTzsa.js";import"./string-oqhohvBP.js";import"./folder-hq2yZXh6.js";import"./ant-design-eu7PrKIH.js";import"./cascaderStore-CC-nSHKt.js";import"./organizationSwitcher-BluHzAK8.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="e37e6c4f-12cb-4a29-83d0-001317cb4a76",t._sentryDebugIdIdentifier="sentry-dbid-e37e6c4f-12cb-4a29-83d0-001317cb4a76")}catch{}})();const q=f({__name:"Organization",setup(t){const e=_(),o=z(),n=i(()=>e.params.organizationId);g(n,a=>{a&&o.fetchedState?.organization?.id!==a&&o.fetchState(a)},{immediate:!0});const d=i(()=>o.fetchedState?.organization),c=i(()=>d.value?.billingMetadata);return(a,h)=>{const u=b("RouterView");return s(),r(p,null,{content:m(()=>[y(l,null,{default:m(()=>[c.value?(s(),r(v,{key:0,"billing-metadata":c.value,"organization-id":n.value},null,8,["billing-metadata","organization-id"])):w("",!0),(s(),r(u,{key:n.value}))]),_:1})]),_:1})}}});export{q as default};
//# sourceMappingURL=Organization-D9wrgqNU.js.map
