import{P as g}from"./PlayerNavbar-2ewOxmRt.js";import{e as _,an as i,r as h,b,f as k,n as y,j as v,k as w,p as n,v as L,a9 as C,aj as I,g as c,aP as N}from"./jwt-decode.esm-DRghvhGH.js";import{u as V}from"./workspaceStore-6xAxtabw.js";import"./userStore-DJ7XWmCi.js";import"./metadata-P1Jr0bFd.js";import"./PhHouse.vue-DmzIWuil.js";import"./PhMagnifyingGlass.vue-BouCj7uB.js";import"./PhWebhooksLogo.vue-DTqW-wOt.js";import"./LoadingOutlined-DQ4EY_C4.js";import"./PhSignOut.vue-eUAYwGjL.js";import"./index-CmAON_bb.js";import"./runnerData-DyO4ndh_.js";import"./url-b_OS5ik_.js";import"./colorHelpers-BNJ_0v5x.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="16876bbf-c619-49aa-a4f1-7d9a87263662",o._sentryDebugIdIdentifier="sentry-dbid-16876bbf-c619-49aa-a4f1-7d9a87263662")}catch{}})();const B={class:"main-container"},D={class:"content"},P=_({__name:"Main",setup(o){const e=I(),t=V(),p=i().path,a=h(null),u=async({path:r,id:s})=>{a.value=s,await e.push({path:`/${r}`}),a.value=null},d=()=>{e.push({name:"playerLogin"})},l=()=>{e.push({name:"playerLogin"})},m=b(()=>!!i().meta.hideLogin);return(r,s)=>{const f=C("RouterView");return c(),k("div",B,[n(t).state.workspace?(c(),y(g,{key:0,"current-path":n(p),"hide-login":m.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:u,onLoginClick:l,onLogoutClick:d},null,8,["current-path","hide-login","runner-data","loading"])):v("",!0),w("section",D,[L(f)])])}}}),J=N(P,[["__scopeId","data-v-f095bece"]]);export{J as default};
//# sourceMappingURL=Main-ZAO7bVLq.js.map
